==> htlpr-0.52.tar.gz: htlpr-0.52/convert.c <==
#include "config.h"

extern int tab;
extern char marginx[];
extern char marginy[];
extern char *fontsize[];
extern int fsize;
extern int pagenum;
extern char *fontstyle[];
extern int fstyle;
extern int border;

void WriteTemp( int , int, int );
void DoVerb( int, char );
void WriteString( int , char [] );
void PrintHead( int );
void PrintTail( int );

int ConvertToLatex( int fd, int temp )
{
	char buf[MAXBUF+1];
	char tms[30];
	char tms2[10];
	int n, j, i;
	int index;
	int space;

	space = 0;
	PrintHead( temp );
	while( ( n = read( fd, buf, MAXBUF ) ) > 0 ) {
		index = 0;
		while( index != n )	{
			if( ( buf[index] != ' ' ) && ( space > 0  ) ) {
				if( space == 1 )
					WriteTemp( temp, ' ', 0 );
				else {
					itoa( space, tms2 );
					sprintf( tms, "\\hspace*{%sex}", tms2 );
					WriteString( temp, tms );
				}
				space = 0;
			}
			switch( buf[index] ) {
				case '%':
				case '$':
				case '&':
				case '#':
				case '_':
				case '-':
				case '{':
				case '}':
				case '~':
				case '\\':
				case '<':
				case '>':
				case '^':
					DoVerb( temp,  buf[index] );
					break;
				case '|':
					WriteString( temp, "\\verb+|+" );
					break;
				case '\t':
					itoa( tab, tms2 );
					sprintf( tms, "\\hspace*{%sex}", tms2 );
					WriteString( temp, tms );
					break;
				case ' ':
					space++;
					break;
				case '\n':
					WriteString( temp, "\\\\\n" );
					break;
				default:
					WriteTemp( temp, (int)buf[index], 0 );
					break;
			}
			index++;
		}
	}
	PrintTail( temp );
	WriteTemp( temp, 0, 1 );
	return 0;
}

void WriteTemp( int fd, int c, int t )
{
	static index = 0;
	static char buf[MAXBUF+1];

	if( t != 1 ) {
		buf[index] = c;
		index++;
	}
	if( t == 1 || index >= MAXBUF ) {
		write( fd, buf, index );
		index = 0;
	}
}

void WriteString( int fd, char string[] )
{
	int i;

	for( i = 0; string[i]; i++ )
		WriteTemp( fd, (int)string[i], 0 );
}

void DoVerb( int fd, char c )
{
	char string[15];

	sprintf( string, "\\verb|%c|", c );
	WriteString( fd, string );
}

void PrintHead( int fd )
{
	char string[100];

	if( border == NO ) 
		WriteString( fd, "\\documentstyle[a4wide]{hreport}\n" );
	else
		WriteString( fd, "\\documentstyle[a4wide,lslide]{hreport}\n" );

	WriteString( fd, "\\setlength{\\textwidth}{18cm}\n" );
	WriteString( fd, "\\setlength{\\textheight}{24cm}\n" );
	WriteString( fd, "\\setlength{\\topmargin}{-1.3cm}\n" );
	WriteString( fd, "\\setlength{\\oddsidemargin}{-1.3cm}\n" );
	WriteString( fd, "\\setlength{\\evensidemargin}{-1.3cm}\n" );

	sprintf( string, "\\voffset = %s in\n", marginx );
	WriteString( fd, string );
	sprintf( string, "\\hoffset = %s in\n", marginy );
	WriteString( fd, string );

	if( pagenum == YES ) 
		sprintf( string, "\\pagestyle{plain}\n" );
	else 
		sprintf( string, "\\pagestyle{empty}\n" );
	WriteString( fd, string );
	
	WriteString( fd, "\\begin{document}\n" );

	sprintf( string, "\\%s", fontsize[fsize] );
	WriteString( fd, string );

	if( fstyle > 0 ) {
		sprintf( string, "\\%s", fontstyle[fstyle] );
		WriteString( fd, string );
	}
	WriteString( fd, "\\noindent\n" );
}

void PrintTail( int fd )
{
	WriteString( fd, "\\end{document}\n" );
}

==> htlpr-0.53.tar.gz: htlpr-0.53/convert.c <==
#include "config.h"

extern int tab;
extern char marginx[];
extern char marginy[];
extern char *fontsize[];
extern int fsize;
extern int pagenum;
extern char *fontstyle[];
extern int fstyle;
extern int border;
extern int title;
extern char Title[];

void WriteTemp( int , int, int );
void DoVerb( int, char );
void WriteString( int , char [] );
void PrintHead( int );
void PrintTail( int );

int ConvertToLatex( int fd, int temp )
{
	char buf[MAXBUF+1];
	char tms[30];
	char tms2[10];
	int n, j, i;
	int index;
	int space;

	space = 0;
	PrintHead( temp );
	while( ( n = read( fd, buf, MAXBUF ) ) > 0 ) {
		index = 0;
		while( index != n )	{
			if( ( buf[index] != ' ' ) && ( space > 0  ) ) {
				if( space == 1 )
					WriteTemp( temp, ' ', 0 );
				else {
					itoa( space, tms2 );
					sprintf( tms, "\\hspace*{%sex}", tms2 );
					WriteString( temp, tms );
				}
				space = 0;
			}
			switch( buf[index] ) {
				case '%':
				case '$':
				case '&':
				case '#':
				case '_':
				case '-':
				case '{':
				case '}':
				case '~':
				case '\\':
				case '<':
				case '>':
				case '^':
					DoVerb( temp,  buf[index] );
					break;
				case '|':
					WriteString( temp, "\\verb+|+" );
					break;
				case '\t':
					itoa( tab, tms2 );
					sprintf( tms, "\\hspace*{%sex}", tms2 );
					WriteString( temp, tms );
					break;
				case ' ':
					space++;
					break;
				case '\n':
					WriteString( temp, "\\\\\n" );
					break;
				default:
					WriteTemp( temp, (int)buf[index], 0 );
					break;
			}
			index++;
		}
	}
	PrintTail( temp );
	WriteTemp( temp, 0, 1 );
	return 0;
}

void WriteTemp( int fd, int c, int t )
{
	static index = 0;
	static char buf[MAXBUF+1];

	if( t != 1 ) {
		buf[index] = c;
		index++;
	}
	if( t == 1 || index >= MAXBUF ) {
		write( fd, buf, index );
		index = 0;
	}
}

void WriteString( int fd, char string[] )
{
	int i;

	for( i = 0; string[i]; i++ )
		WriteTemp( fd, (int)string[i], 0 );
}

void DoVerb( int fd, char c )
{
	char string[15];

	sprintf( string, "\\verb|%c|", c );
	WriteString( fd, string );
}

void PrintHead( int fd )
{
	char string[100];

	if( border == NO ) 
		WriteString( fd, "\\documentstyle[a4wide]{hreport}\n" );
	else
		WriteString( fd, "\\documentstyle[a4wide,lslide]{hreport}\n" );

	WriteString( fd, "\\setlength{\\textwidth}{18cm}\n" );
	WriteString( fd, "\\setlength{\\textheight}{24cm}\n" );
	WriteString( fd, "\\setlength{\\topmargin}{-1.3cm}\n" );
	WriteString( fd, "\\setlength{\\oddsidemargin}{-1.3cm}\n" );
	WriteString( fd, "\\setlength{\\evensidemargin}{-1.3cm}\n" );

	sprintf( string, "\\voffset = %s in\n", marginx );
	WriteString( fd, string );
	sprintf( string, "\\hoffset = %s in\n", marginy );
	WriteString( fd, string );

	if( title == YES ) 
		sprintf( string, "\\pagestyle{myheadings}\n\\markboth{%s}{%s}\n",
			Title, Title );
	else if( pagenum == YES ) 
		sprintf( string, "\\pagestyle{plain}\n" );
	else 
		sprintf( string, "\\pagestyle{empty}\n" );
	WriteString( fd, string );
	
	WriteString( fd, "\\begin{document}\n" );

	sprintf( string, "\\%s", fontsize[fsize] );
	WriteString( fd, string );

	if( fstyle > 0 ) {
		sprintf( string, "\\%s", fontstyle[fstyle] );
		WriteString( fd, string );
	}
	WriteString( fd, "\\noindent\n" );
}

void PrintTail( int fd )
{
	WriteString( fd, "\\end{document}\n" );
}
